Header

Struct Header 

#[repr(C, packed(1))]
pub struct Header { pub magic: u32, pub min: [u16; 3], pub max: [u16; 3], pub mode: ExecMode, pub sections: u16, pub author: [u8; 32], pub name: [u8; 32], pub extended: [u8; 42], }
The main header struct, which contains the metadata of the PKE file.

Fields

magic: u32

The magic number, fixed to ‘PKEX’

min: [u16; 3]

The minimal kernel version supported.

Note

As the proka-bootloader’s definitions, its format is similar like [major, minor, fix]. See proka-bootloader crate for more informations.

max: [u16; 3]

The maximum kernel supported.

For notes, see above.

mode: ExecMode

Signates is this executable run as userapp or coredrv.

sections: u16

The section table count.

author: [u8; 32]

The author name (max length is 32 bytes).

name: [u8; 32]

The executable/project name.

extended: [u8; 42]

Extended bits for different mode parsing.

Implementations

Source

impl Header

pub fn new() -> Self

Create a header object.

pub fn validate(&self) -> bool

Validate is this a valid proka executable.

pub const fn to_array(&self) -> [u8; 128]

Convert this header to array