Crate proka_exec

Crate proka_exec 

proka-exec

Rust Nightly License: GPLv3 GitHub Stars GitHub Issues GitHub Pull Requests Documentation

Copyright (C) 2026 RainSTR Studio. All rights reserved.


Introduction

This crate provides the definitions of headers, section entrys, and some utils to help you parse the executable easily.

Steps to use this crate

Before you parse it, you should do these steps:

  • Read the executable file content;
  • Make this file’s content to a slice (&'static [u8])
  • Use Parser to parse the executable.

After this, you can do further operations through this parser by calling its functions.

Note

If you want to do minimal reading, you can just read the header and section table, other content can be read later;

Make sure you have read the header and each sections, and they are NOT optional!!!

LICENSE

This crate is under license GPL-v3, and you must follow its rules.

See LICENSE file for more details.

MSRV

This crate’s MSRV is 1.85.0 stable.

Re-exports

pub use utils::*;

Modules

header
The header definitions.
sections
The definitions of section entry.
utils
Utilities to parse proka exec headers.

Structs

Parser
The parser of the proka executable.

Enums

Error
The error type of parsing header.

Constants

HEADER_SIZE
The header size.
SECTION_SIZE
The section entry size