#[repr(C, packed(1))]pub struct Header {
pub magic: u32,
pub min: [u16; 3],
pub max: [u16; 3],
pub mode: ExecMode,
pub sections: u16,
pub entry_sec: u16,
pub entry_off: u32,
pub author: [u8; 32],
pub name: [u8; 32],
pub extended: [u8; 36],
}Expand description
The main header struct, which contains the metadata of the PKE file.
Fields
magic: u32The magic number, fixed to ‘PKEX’
min: [u16; 3]The minimal kernel version supported.
Note
As the proka-bootloader’s definitions, its format is similar
like [major, minor, fix]. See proka-bootloader crate for more informations.
max: [u16; 3]The maximum kernel supported.
For notes, see above.
mode: ExecModeSignates is this executable run as userapp or coredrv.
sections: u16The section table count.
entry_sec: u16The section which contains the entry point.
entry_off: u32The entry offset of the section.
The author name (max length is 32 bytes).
name: [u8; 32]The executable/project name.
extended: [u8; 36]Extended bits for different mode parsing (reserved).
Implementations