SectionError

Enum SectionError 

pub enum SectionError {
    LengthError,
    BaseError(u32),
    EntryOffsetOutOfRange(u32, u32),
}
Errors in section

Variants



LengthError

Section length error.

Will appear if recorded section length is 0.



BaseError(u32)

Section base error.

Will appear if specified section base is lower than metadata length (128+32).

Contains the incorrect base.



EntryOffsetOutOfRange(u32, u32)

Entry offset out of range.

Will appear if entry offset is out of range of the section.

Contains the incorrect entry offset (0) and the section length (1).